All of lore.kernel.org
 help / color / mirror / Atom feed
* [U-Boot] [PATCH 1/6] Davinci: ea20: set console on UART0
@ 2011-04-09 18:05 Stefano Babic
  2011-04-09 18:05 ` [U-Boot] [PATCH 2/6] Davinci: ea20: set GPIOs to hold MII-Phy in reset and set UART0-Switch for console Stefano Babic
                   ` (4 more replies)
  0 siblings, 5 replies; 22+ messages in thread
From: Stefano Babic @ 2011-04-09 18:05 UTC (permalink / raw)
  To: u-boot

From: Bastian Ruppert <Bastian.Ruppert@Sewerin.de>

Signed-off-by: Bastian Ruppert <Bastian.Ruppert@Sewerin.de>
Signed-off-by: Stefano Babic <sbabic@denx.de>
CC: Sandeep Paulraj <s-paulraj@ti.com>
---
 arch/arm/include/asm/arch-davinci/hardware.h |    2 +-
 board/davinci/ea20/ea20.c                    |   16 ++++++++--------
 include/configs/ea20.h                       |    2 +-
 3 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/arch/arm/include/asm/arch-davinci/hardware.h b/arch/arm/include/asm/arch-davinci/hardware.h
index df3f549..1892f15 100644
--- a/arch/arm/include/asm/arch-davinci/hardware.h
+++ b/arch/arm/include/asm/arch-davinci/hardware.h
@@ -412,7 +412,7 @@ struct davinci_syscfg_regs {
 #define DAVINCI_SYSCFG_SUSPSRC_I2C		(1 << 16)
 #define DAVINCI_SYSCFG_SUSPSRC_SPI0		(1 << 21)
 #define DAVINCI_SYSCFG_SUSPSRC_SPI1		(1 << 22)
-#define DAVINCI_SYSCFG_SUSPSRC_UART2		(1 << 20)
+#define DAVINCI_SYSCFG_SUSPSRC_UART0		(1 << 18)
 #define DAVINCI_SYSCFG_SUSPSRC_TIMER0		(1 << 27)
 
 /* Interrupt controller */
diff --git a/include/configs/ea20.h b/include/configs/ea20.h
index 48ce945..601990a 100644
--- a/include/configs/ea20.h
+++ b/include/configs/ea20.h
@@ -67,7 +67,7 @@
 #define CONFIG_SYS_NS16550
 #define CONFIG_SYS_NS16550_SERIAL
 #define CONFIG_SYS_NS16550_REG_SIZE	-4	/* NS16550 register size */
-#define CONFIG_SYS_NS16550_COM1	DAVINCI_UART2_BASE /* Base address of UART2 */
+#define CONFIG_SYS_NS16550_COM1	DAVINCI_UART0_BASE /* Base address of UART0 */
 #define CONFIG_SYS_NS16550_CLK	clk_get(DAVINCI_UART2_CLKID)
 #define CONFIG_CONS_INDEX	1		/* use UART0 for console */
 #define CONFIG_BAUDRATE		115200		/* Default baud rate */
diff --git a/board/davinci/ea20/ea20.c b/board/davinci/ea20/ea20.c
index 9d0f71b..4e4107a 100644
--- a/board/davinci/ea20/ea20.c
+++ b/board/davinci/ea20/ea20.c
@@ -48,12 +48,12 @@ static const struct pinmux_config spi1_pins[] = {
 	{ pinmux(5), 1, 5 }
 };
 
 /* UART pin muxer settings */
 static const struct pinmux_config uart_pins[] = {
-	{ pinmux(0), 4, 6 },
-	{ pinmux(0), 4, 7 },
-	{ pinmux(4), 2, 4 },
-	{ pinmux(4), 2, 5 }
+	{ pinmux(3), 2, 7 },
+	{ pinmux(3), 2, 6 },
+	{ pinmux(3), 2, 4 },
+	{ pinmux(3), 2, 5 }
 };
 
 #ifdef CONFIG_DRIVER_TI_EMAC
@@ -104,7 +104,7 @@ static const struct lpsc_resource lpsc[] = {
 	{ DAVINCI_LPSC_AEMIF },	/* NAND, NOR */
 	{ DAVINCI_LPSC_SPI1 },	/* Serial Flash */
 	{ DAVINCI_LPSC_EMAC },	/* image download */
-	{ DAVINCI_LPSC_UART2 },	/* console */
+	{ DAVINCI_LPSC_UART0 },	/* console */
 	{ DAVINCI_LPSC_GPIO },
 };
 
@@ -150,7 +150,7 @@ int board_init(void)
 	writel(readl(&davinci_syscfg_regs->suspsrc) &
 	       ~(DAVINCI_SYSCFG_SUSPSRC_EMAC | DAVINCI_SYSCFG_SUSPSRC_I2C |
 		 DAVINCI_SYSCFG_SUSPSRC_SPI1 | DAVINCI_SYSCFG_SUSPSRC_TIMER0 |
-		 DAVINCI_SYSCFG_SUSPSRC_UART2),
+		 DAVINCI_SYSCFG_SUSPSRC_UART0),
 	       &davinci_syscfg_regs->suspsrc);
 
 	/* configure pinmux settings */
@@ -167,7 +167,7 @@ int board_init(void)
 	/* enable the console UART */
 	writel((DAVINCI_UART_PWREMU_MGMT_FREE | DAVINCI_UART_PWREMU_MGMT_URRST |
 		DAVINCI_UART_PWREMU_MGMT_UTRST),
-	       &davinci_uart2_ctrl_regs->pwremu_mgmt);
+	       &davinci_uart0_ctrl_regs->pwremu_mgmt);
 
 	return 0;
 }
@@ -48,12 +48,12 @@ static const struct pinmux_config spi1_pins[] = {
 };
 
-/* UART pin muxer settings */
+/* UART0 pin muxer settings */
 static const struct pinmux_config uart_pins[] = {
-- 
1.7.1

^ permalink raw reply related	[flat|nested] 22+ messages in thread

end of thread, other threads:[~2011-04-25 17:37 UTC | newest]

Thread overview: 22+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2011-04-09 18:05 [U-Boot] [PATCH 1/6] Davinci: ea20: set console on UART0 Stefano Babic
2011-04-09 18:05 ` [U-Boot] [PATCH 2/6] Davinci: ea20: set GPIOs to hold MII-Phy in reset and set UART0-Switch for console Stefano Babic
2011-04-09 18:05 ` [U-Boot] [PATCH 3/6] Davinci: ea20: Add NAND support Stefano Babic
2011-04-11 13:05   ` Ben Gardiner
2011-04-12  7:29     ` Stefano Babic
2011-04-12 16:09       ` Ben Gardiner
2011-04-09 18:05 ` [U-Boot] [PATCH 4/6] Davinci: ea20: Add early init to get early output from console Stefano Babic
2011-04-09 18:05 ` [U-Boot] [PATCH 5/6] Davinci: ea20: Add default U-Boot environment Stefano Babic
2011-04-09 18:05 ` [U-Boot] [PATCH 6/6] EA20: do not use subpage write for NAND Stefano Babic
2011-04-11 14:04   ` Ben Gardiner
2011-04-12  0:45     ` Jon Povey
2011-04-12  0:45       ` [U-Boot] " Jon Povey
2011-04-12  9:08     ` Stefano Babic
2011-04-12 12:47       ` Ben Gardiner
2011-04-12 12:47         ` [U-Boot] " Ben Gardiner
2011-04-11 19:16   ` Scott Wood
2011-04-12  9:44     ` Stefano Babic
2011-04-13 16:24       ` Scott Wood
2011-04-15 17:34         ` Stefano Babic
2011-04-15 20:29           ` Scott Wood
2011-04-22  7:13             ` Stefano Babic
2011-04-25 17:37               ` Scott Wood

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.